use std::fs;

use crate::parse::string_to_numbers;

pub fn read_to_lines(_filename: &str) -> Result<Vec<String>, String> {
    let _contents = fs::read_to_string(_filename);
    if let Err(v) = _contents {
        return Err(format!("Could not read file: {}", v));
    }

    let lines = _contents.unwrap().lines().map(|x| x.to_string()).collect::<Vec<String>>();

    Ok(lines)
}

pub fn read_to_string(_filename: &str) -> Result<String, String> {
    let _lines = read_to_lines(_filename);

    match _lines {
        Ok(lines) => if lines.len() >= 1 {
            Ok(lines[0].clone())
        } else {
            Err(String::from("Missing content"))
        },
        Err(v) => Err(v)
    }
}

pub fn read_to_matrix(_filename: &str) -> Result<Vec<Vec<i128>>, String> {
    let _lines = read_to_lines(_filename);

    if let Err(v) = _lines {
        return Err(v);
    }

    Ok(_lines
        .unwrap()
        .iter()
        .map(|x| string_to_numbers(x.to_string()))
        .collect()
    )
}